@@ -1,3 +1,12 @@
+#
+# This file is part of Config-Model-Itself
+#
+# This software is Copyright (c) 2010 by Dominique Dumont.
+#
+# This is free software, licensed under:
+#
+#   The GNU Lesser General Public License, Version 2.1, February 1999
+#
 [
  [
    name => "MasterModel::CheckListExamples",
@@ -23,6 +32,13 @@
 	    help => { A => 'A help', E => 'E help' } ,
 	  },
 
+       choice_list_with_upstream_default_list
+       => { type          => 'check_list',
+	    choice        => ['A' .. 'Z'],
+	    upstream_default_list => [ 'A', 'D' ],
+	    help          => { A => 'A help', E => 'E help' } ,
+	  },
+
        macro => { type => 'leaf',
 		  value_type => 'enum',
 		  choice     => [qw/AD AH/],
