@@ -1,3 +1,12 @@
+#
+# This file is part of Config-Model-Itself
+#
+# This software is Copyright (c) 2010 by Dominique Dumont.
+#
+# This is free software, licensed under:
+#
+#   The GNU Lesser General Public License, Version 2.1, February 1999
+#
 # $Author: ddumont $
 # $Date: 2008-04-14 15:57:49 +0200 (Mon, 14 Apr 2008) $
 # $Revision: 604 $
@@ -43,6 +52,22 @@
 	   choice => [qw/important normal hidden/] ,
 	  },
 
+      'index_type' 
+      => { type => 'leaf',
+	   value_type => 'enum',
+	   level      => 'hidden' ,
+	   warp => { follow => '?type',
+		     'rules'
+		     => { 'hash' => {
+				     level => 'important',
+				     #mandatory => 1,
+				     choice => [qw/string integer/] ,
+				    }
+			}
+		   },
+	   description => 'Specify the type of allowed index for the hash. "String" means no restriction.',
+	 },
+
       ],
 
    'description' 
